![gb logo, a gopher in a ball](https://src.tty.cat/supakeen/gb/raw/branch/master/doc/_static/logo-doc.png)

# gb

![rtd badge](https://readthedocs.org/projects/gb/badge/?version=latest) ![license badge](https://gb.readthedocs.io/en/latest/_static/license.svg) ![black badge](https://img.shields.io/badge/code%20style-black-000000.svg)

## About
`gb` or gopherball is a gopher library written in Python with the main goals of
ease of use and integration. The name gopherball is inspired by a recurring
theme in the Calvin & Hobbes comicbooks and a tongue in cheek reference of an
alternative to the World Wide Web as we know it today.

## Examples
There are several other projects that are built on top of `gb` to get you running:

### Server
Check out the [gbs](https://github.com/supakeen/gbs) project.

### Client
Check out the [gbc](https://github.com/supakeen/gbc) project.

### Proxy
Check out the [gbx](https://github.com/supakeen/gbx) project.

## Technology
`gb` is written with the help of Python 3.9 and higher and the Tornado
framework for its networking.

## Contributing
The source code for `gb` lives on my GitHub where you can also submit issues
and pull requests. It mostly needs help by people with the ability to test in
various clients and libraries that might still support the gopher protocol.
